@@ -1,7 +1,7 @@
 """
 Plugin for Pyramid apps to submit errors to Rollbar
 """
-__version__ = '0.9.2'
+__version__ = '0.9.3'
 
 import copy
 import inspect
@@ -114,21 +114,29 @@ def get_request():
 
 
 def _get_bottle_request():
+    if BottleRequest is None:
+        return None
     from bottle import request
     return request
 
 
 def _get_flask_request():
+    if WerkzeugRequest is None:
+        return None
     from flask import request
     return request
 
 
 def _get_pyramid_request():
+    if WebobBaseRequest is None:
+        return None
     from pyramid.threadlocal import get_current_request
     return get_current_request()
 
 
 def _get_pylons_request():
+    if WebobBaseRequest is None:
+        return None
     from pylons import request
     return request
 
@@ -393,10 +401,33 @@ class PagedResult(Result):
 
 ## internal functions
 
+# Python 2.x and 3.x compatible string test
+try:
+    isinstance('', basestring)
+    def isstr(s):
+        return isinstance(s, basestring)
+except NameError:
+    def isstr(s):
+        return isinstance(s, str)
+
+
+def _resolve_exception_class(idx, filter):
+    cls, level = filter
+    if isstr(cls):
+        # Lazily resolve class name
+        parts = cls.split('.')
+        module = ".".join(parts[:-1])
+        if module in sys.modules and hasattr(sys.modules[module], parts[-1]):
+            cls = getattr(sys.modules[module], parts[-1])
+            SETTINGS['exception_level_filters'][idx] = (cls, level)
+        else:
+            cls = None
+    return cls, level
 
 def _filtered_level(exception):
-    for cls, level in SETTINGS['exception_level_filters']:
-        if isinstance(exception, cls):
+    for i, filter in enumerate(SETTINGS['exception_level_filters']):
+        cls, level = _resolve_exception_class(i, filter)
+        if cls and isinstance(exception, cls):
             return level
 
     return None
